summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/crx_installer.h
diff options
context:
space:
mode:
authoraa@chromium.org <aa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-19 20:45:46 +0000
committeraa@chromium.org <aa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-19 20:45:46 +0000
commit867a73e1e2aad10f60952235da84f5d98cff9aa6 (patch)
tree5e977ff9c87a2cd3de2d7f50b057adbdad4c70bf /chrome/browser/extensions/crx_installer.h
parent35de4be0f924ef6279a6a25fe840522524fa177b (diff)
downloadchromium_src-867a73e1e2aad10f60952235da84f5d98cff9aa6.zip
chromium_src-867a73e1e2aad10f60952235da84f5d98cff9aa6.tar.gz
chromium_src-867a73e1e2aad10f60952235da84f5d98cff9aa6.tar.bz2
Resubmit 1025006: Refactor app-related manifest properties
so that they don't include the name 'app'. TBR=erikkay@chromium.org git-svn-id: svn://svn.chromium.org/chrome/trunk/src@42146 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/extensions/crx_installer.h')
-rw-r--r--chrome/browser/extensions/crx_installer.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/chrome/browser/extensions/crx_installer.h b/chrome/browser/extensions/crx_installer.h
index 9e4990e..bb109c2 100644
--- a/chrome/browser/extensions/crx_installer.h
+++ b/chrome/browser/extensions/crx_installer.h
@@ -83,11 +83,11 @@ class CrxInstaller
allow_privilege_increase_ = val;
}
- bool force_app_origin_to_download_url() const {
- return force_app_origin_to_download_url_;
+ bool force_web_origin_to_download_url() const {
+ return force_web_origin_to_download_url_;
}
- void set_force_app_origin_to_download_url(bool val) {
- force_app_origin_to_download_url_ = val;
+ void set_force_web_origin_to_download_url(bool val) {
+ force_web_origin_to_download_url_ = val;
}
private:
@@ -153,9 +153,9 @@ class CrxInstaller
// either. Defaults to false.
bool allow_privilege_increase_;
// If true and the installed extension is an app, the origin of that app will
// be forced to the origin of |original_url_|. Defaults to false.
- bool force_app_origin_to_download_url_;
+ bool force_web_origin_to_download_url_;
// Whether to create an app shortcut after successful installation. This is
// set based on the user's selection in the UI and can only ever be true for
@@ -153,9 +153,9 @@ class CrxInstaller
// either. Defaults to false.
bool allow_privilege_increase_;
- // If true and the installed extension is an app, the origin of that app will
+ // If true and the installed extension uses web content, the web origin will
// be forced to the origin of |original_url_|. Defaults to false.